@@ -95,7 +95,7 @@
  *
  * Possible Values:
  *  0 = disable dynamic device file management
- *  1 = enable  dynamic device file management (default)
+ *  1 = enable  dynamic device file management
  */
 
 #define __NV_MODIFY_DEVICE_FILES ModifyDeviceFiles
@@ -240,39 +240,6 @@
 #define __NV_REGISTRY_DWORDS RegistryDwords
 #define NV_REG_REGISTRY_DWORDS NV_REG_STRING(__NV_REGISTRY_DWORDS)
 
-/*
- * Option: RegistryDwordsPerDevice
- *
- * Description:
- *
- * This option allows to specify registry keys per GPU device. It helps to
- * control registry at GPU level of granularity. It accepts a semicolon
- * separated list of key=value pairs. The first key value pair MUST be
- * "pci=DDDD:BB:DD.F;" where DDDD is Domain, BB is Bus Id, DD is device slot
- * number and F is the Function. This PCI BDF is used to identify which GPU to
- * assign the registry keys that follows next.
- * If a GPU corresponding to the value specified in "pci=DDDD:BB:DD.F;" is NOT
- * found, then all the registry keys that follows are skipped, until we find next
- * valid pci identified "pci=DDDD:BB:DD.F;". Following are the valid formats for
- * the value of the "pci" string:
- * 1)  bus:slot                 : Domain and function defaults to 0.
- * 2)  domain:bus:slot          : Function defaults to 0.
- * 3)  domain:bus:slot.func     : Complete PCI dev id string.
- *
- * For each of the registry keys that follows, key name is checked against the
- * table of static options; if a match is found, the static option value is
- * overridden, but invalid options remain invalid. Pairs that do not match an
- * entry in the static option table are passed on to the RM directly.
- *
- * Format:
- *
- *  NVreg_RegistryDwordsPerDevice="pci=DDDD:BB:DD.F;<key=value>;<key=value>;..; \
- *               pci=DDDD:BB:DD.F;<key=value>;..;"
- */
-
-#define __NV_REGISTRY_DWORDS_PER_DEVICE RegistryDwordsPerDevice
-#define NV_REG_REGISTRY_DWORDS_PER_DEVICE NV_REG_STRING(__NV_REGISTRY_DWORDS_PER_DEVICE)
-
 #define __NV_RM_MSG RmMsg
 #define NV_RM_MSG NV_REG_STRING(__NV_RM_MSG)
 
@@ -317,8 +284,8 @@
  *
  * Possible Values:
  *
- *  0 = disable MSI interrupt
- *  1 = enable MSI interrupt (default)
+ *  0 = disable MSI interrupt (default on x86/x86-64)
+ *  1 = enable MSI interrupt (default on ARM)
  *
  */
 
@@ -435,180 +402,14 @@
  * Description:
  *
  * When set to a non-zero value, this option specifies the size of the
- * memory pool, given as a multiple of 1 GB, created on VMware ESXi to
- * satisfy any system memory allocations requested by the NVIDIA kernel
- * module.
+ * memory pool, given as a multiple of 4KB pages, created on VMware
+ * ESXi to satisfy any system memory allocations requested by the NVIDIA
+ * kernel module.
  */
 
 #define __NV_MEMORY_POOL_SIZE MemoryPoolSize
 #define NV_REG_MEMORY_POOL_SIZE NV_REG_STRING(__NV_MEMORY_POOL_SIZE)
 
-/*
- * Option: IgnoreMMIOCheck
- *
- * Description:
- *
- * When this option is enabled, the NVIDIA kernel module will ignore
- * MMIO limit check during device probe on VMWare ESXi kernel. This is
- * typically necessary when VMware ESXi MMIO limit differs between any
- * base version and its updates. Customer using updates can set regkey
- * to avoid probe failure.
- */
-
-#define __NV_IGNORE_MMIO_CHECK IgnoreMMIOCheck
-#define NV_REG_IGNORE_MMIO_CHECK NV_REG_STRING(__NV_IGNORE_MMIO_CHECK)
-
-/*
- * Option: TCEBypassMode
- *
- * Description:
- *
- * When this option is enabled, the NVIDIA kernel module will attempt to setup
- * all GPUs in "TCE bypass mode", in which DMA mappings of system memory bypass
- * the IOMMU/TCE remapping hardware on IBM POWER systems. This is typically
- * necessary for CUDA applications in which large system memory mappings may
- * exceed the default TCE remapping capacity when operated in non-bypass mode.
- *
- * This option has no effect on non-POWER platforms.
- *
- * Possible Values:
- * 
- *  0: system default TCE mode on all GPUs
- *  1: enable TCE bypass mode on all GPUs
- *  2: disable TCE bypass mode on all GPUs
- */
-#define __NV_TCE_BYPASS_MODE TCEBypassMode
-#define NV_REG_TCE_BYPASS_MODE NV_REG_STRING(__NV_TCE_BYPASS_MODE)
-
-#define NV_TCE_BYPASS_MODE_DEFAULT  0
-#define NV_TCE_BYPASS_MODE_ENABLE   1
-#define NV_TCE_BYPASS_MODE_DISABLE  2
-
-/*
- * Option: UseThreadedInterrupts
- *
- * Description:
- *
- * When this option is enabled and the host kernel supports the
- * request_threaded_irq feature, the NVIDIA driver will call
- * request_threaded_irq and will therefore NOT use tasklets for the bottom half
- * ISR handler. This is instead of: calling request_irq and using tasklets.
- *
- * So far, this only affects GPU interrupts. Other device interrupts, such as
- * the GVI device, could eventually honor this mechanism, but they do not right
- * now.
- *
- * Possible Values:
- *
- *  0 = use request_irq to set up the interrupt handler.
- *  1 = use request_threaded_irq to set up the interrupt handler (default)
- */
-#define __NV_USE_THREADED_INTERRUPTS UseThreadedInterrupts
-#define NV_REG_USE_THREADED_INTERRUPTS NV_REG_STRING(__NV_USE_THREADED_INTERRUPTS)
-
-/*
- * Option: pci
- *
- * Description:
- *
- * On Unix platforms, per GPU based registry key can be specified as: 
- * NVreg_RegistryDwordsPerDevice="pci=DDDD:BB:DD.F,<per-gpu registry keys>".
- * where DDDD:BB:DD.F refers to Domain:Bus:Device.Function.
- * We need this key "pci" to identify what follows next is a PCI BDF identifier, 
- * for which the registry keys are to be applied.
- *
- * This define is not used on non-UNIX platforms.
- *
- * Possible Formats for value:
- *
- * 1)  bus:slot                 : Domain and function defaults to 0.
- * 2)  domain:bus:slot          : Function defaults to 0.
- * 3)  domain:bus:slot.func     : Complete PCI BDF identifier string.
- */
-#define __NV_PCI_DEVICE_BDF pci
-#define NV_REG_PCI_DEVICE_BDF NV_REG_STRING(__NV_PCI_DEVICE_BDF)
-
-/*
- * Option: EnableStreamMemOPs
- *
- * Description:
- *
- * When this option is enabled, the CUDA driver will enable support for
- * CUDA Stream Memory Operations in user-mode applications, which are so
- * far required to be disabled by default due to limited support in
- * devtools.
- *
- * Note: this is treated as a hint. MemOPs may still be left disabled by CUDA
- * driver for other reasons.
- *
- * Possible Values:
- *
- *  0 = disable feature (default)
- *  1 = enable feature
- */
-#define __NV_ENABLE_STREAM_MEMOPS EnableStreamMemOPs
-#define NV_REG_ENABLE_STREAM_MEMOPS NV_REG_STRING(__NV_ENABLE_STREAM_MEMOPS)
-
-/*
- * Option: EnableBacklightHandler
- *
- * Description:
- *
- * When this option is enabled and the platform supports it, the NVIDIA driver
- * will register a backlight handler with the operating system.
- *
- * The backlight handler will be registered when the corresponding device is
- * initialized, and will be removed when the device is shut down.
- *
- * Possible Values:
- *
- *  0 = disable feature (default)
- *  1 = enable feature
- */
-#define __NV_ENABLE_BACKLIGHT_HANDLER EnableBacklightHandler
-#define NV_REG_ENABLE_BACKLIGHT_HANDLER NV_REG_STRING(__NV_ENABLE_BACKLIGHT_HANDLER)
-
-/*
- * Option: EnableUserNUMAManagement
- *
- * Description:
- *
- * When this option is enabled, the NVIDIA kernel module will require the
- * user-mode NVIDIA Persistence daemon to manage the onlining and offlining
- * of its NUMA device memory.
- *
- * This option has no effect on platforms that do not support onlining
- * device memory to a NUMA node (this feature is only supported on certain
- * POWER9 systems).
- *
- * Possible Values:
- * 
- *  0: disable user-mode NUMA management
- *  1: enable user-mode NUMA management (default)
- */
-#define __NV_ENABLE_USER_NUMA_MANAGEMENT EnableUserNUMAManagement
-#define NV_REG_ENABLE_USER_NUMA_MANAGEMENT NV_REG_STRING(__NV_ENABLE_USER_NUMA_MANAGEMENT)
-
-/*
- * Option: EnableIBMNPURelaxedOrderingMode
- *
- * Description:
- *
- * When this option is enabled, the NVIDIA kernel module will start issuing
- * necessary barriers/synchronizations to ensure I/O consistency on all the
- * registered and compatible NPU devices.
- *
- * Note: this option is intended for testing purposes only and will be removed
- * in a future release.
- *
- * Possible Values:
- * 
- *  0: disable relaxed ordering (default)
- *  1: enable relaxed ordering mode
- */
-#define __NV_ENABLE_IBMNPU_RELAXED_ORDERING_MODE EnableIBMNPURelaxedOrderingMode
-#define NV_REG_ENABLE_IBMNPU_RELAXED_ORDERING_MODE NV_REG_STRING(__NV_ENABLE_IBMNPU_RELAXED_ORDERING_MODE)
-
 #if defined(NV_DEFINE_REGISTRY_KEY_TABLE)
 
 /*
@@ -630,17 +431,9 @@ NV_DEFINE_REG_ENTRY(__NV_REGISTER_FOR_ACPI_EVENTS, 1);
 NV_DEFINE_REG_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE, NV_CHECK_PCI_CONFIG_SPACE_INIT);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_PCIE_GEN3, 0);
 NV_DEFINE_REG_ENTRY(__NV_ENABLE_MSI, 1);
-NV_DEFINE_REG_ENTRY(__NV_TCE_BYPASS_MODE, NV_TCE_BYPASS_MODE_DEFAULT);
-NV_DEFINE_REG_ENTRY(__NV_USE_THREADED_INTERRUPTS, 1);
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_STREAM_MEMOPS, 0);
-NV_DEFINE_REG_ENTRY(__NV_ENABLE_BACKLIGHT_HANDLER, 0);
-NV_DEFINE_REG_ENTRY_GLOBAL(__NV_ENABLE_USER_NUMA_MANAGEMENT, 1);
-NV_DEFINE_REG_ENTRY_GLOBAL(__NV_ENABLE_IBMNPU_RELAXED_ORDERING_MODE, 0);
 NV_DEFINE_REG_ENTRY_GLOBAL(__NV_MEMORY_POOL_SIZE, 0);
-NV_DEFINE_REG_ENTRY_GLOBAL(__NV_IGNORE_MMIO_CHECK, 0);
 
 NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
-NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS_PER_DEVICE, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_RM_MSG, NULL);
 
 #if !defined(NV_VMWARE)
@@ -675,13 +468,6 @@ nv_parm_t nv_parms[] = {
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_CHECK_PCI_CONFIG_SPACE),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_PCIE_GEN3),
     NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_MEMORY_POOL_SIZE),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_IGNORE_MMIO_CHECK),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_TCE_BYPASS_MODE),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_USE_THREADED_INTERRUPTS),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_STREAM_MEMOPS),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_BACKLIGHT_HANDLER),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_USER_NUMA_MANAGEMENT),
-    NV_DEFINE_PARAMS_TABLE_ENTRY(__NV_ENABLE_IBMNPU_RELAXED_ORDERING_MODE),
     {NULL, NULL, NULL}
 };
 
