@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 1999-2017 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 1999-2015 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -12,13 +12,8 @@
 #ifndef _NV_H_
 #define _NV_H_
 
-#include <nvlimits.h>
 #include <nvtypes.h>
-#include <nvCpuUuid.h>
 #include <stdarg.h>
-#ifndef __KERNEL__
-#include "g_nvconfig.h"
-#endif
 
 #if !defined(NV_MIN)
 #define NV_MIN(_a,_b) ((_a) < (_b) ? (_a) : (_b))
@@ -30,6 +25,8 @@
 /* NVIDIA's reserved major character device number (Linux). */
 #define NV_MAJOR_DEVICE_NUMBER 195
 
+/* most cards in a single system */
+#define NV_MAX_DEVICES 32
 #define GPU_UUID_LEN    (16)
 
 typedef struct {
@@ -52,17 +49,12 @@ typedef struct {
 #define NV_ESC_STATUS_CODE       (NV_IOCTL_BASE + 9)
 #define NV_ESC_CHECK_VERSION_STR (NV_IOCTL_BASE + 10)
 #define NV_ESC_IOCTL_XFER_CMD    (NV_IOCTL_BASE + 11)
-#define NV_ESC_ATTACH_GPUS_TO_FD (NV_IOCTL_BASE + 12)
-#define NV_ESC_QUERY_DEVICE_INTR (NV_IOCTL_BASE + 13)
-#define NV_ESC_SYS_PARAMS        (NV_IOCTL_BASE + 14)
-#define NV_ESC_NUMA_INFO         (NV_IOCTL_BASE + 15)
-#define NV_ESC_SET_NUMA_STATUS   (NV_IOCTL_BASE + 16)
 
 /*
  * #define an absolute maximum used as a sanity check for the
  * NV_ESC_IOCTL_XFER_CMD ioctl() size argument.
  */
-#define NV_ABSOLUTE_MAX_IOCTL_SIZE  16384
+#define NV_ABSOLUTE_MAX_IOCTL_SIZE  8192
 
 /*
  * Solaris provides no more than 8 bits for the argument size in
@@ -167,6 +159,14 @@ typedef struct nv_ioctl_free_os_event
     NvU32    Status;
 } nv_ioctl_free_os_event_t;
 
+#define NV_CTL_DEVICE_PCI_DOMAIN        0
+#define NV_CTL_DEVICE_PCI_BUS           255
+#define NV_CTL_DEVICE_PCI_SLOT          255
+
+#define NV_PCI_MATCH_CTL_DEVICE(domain, bus, slot) \
+    (((domain) == NV_CTL_DEVICE_PCI_DOMAIN) && \
+     ((bus) == NV_CTL_DEVICE_PCI_BUS) && ((slot) == NV_CTL_DEVICE_PCI_SLOT))
+
 #define NV_PCI_DEV_FMT          "%04x:%02x:%02x.%x"
 #define NV_PCI_DEV_FMT_ARGS(nv) (nv)->pci_info.domain, (nv)->pci_info.bus, \
                                 (nv)->pci_info.slot, (nv)->pci_info.function
@@ -197,45 +197,6 @@ typedef struct nv_ioctl_rm_api_version
 #define NV_RM_API_VERSION_REPLY_UNRECOGNIZED 0
 #define NV_RM_API_VERSION_REPLY_RECOGNIZED   1
 
-typedef struct nv_ioctl_query_device_intr
-{
-    NvU32 intrStatus NV_ALIGN_BYTES(4);
-    NvU32 status;
-} nv_ioctl_query_device_intr;
-
-#define NV_RM_DEVICE_INTR_ADDRESS 0x100
-
-
-/* system parameters that the kernel driver may use for configuration */
-typedef struct nv_ioctl_sys_params
-{
-    NvU64 memblock_size NV_ALIGN_BYTES(8);
-} nv_ioctl_sys_params_t;
-
-/* per-device NUMA memory info as assigned by the system */
-typedef struct nv_ioctl_numa_info
-{
-    NvS32 nid;
-    NvS32 status;
-    NvU64 memblock_size NV_ALIGN_BYTES(8);
-    NvU64 numa_mem_addr NV_ALIGN_BYTES(8);
-    NvU64 numa_mem_size NV_ALIGN_BYTES(8);
-} nv_ioctl_numa_info_t;
-
-/* set the status of the device NUMA memory */
-typedef struct nv_ioctl_set_numa_status
-{
-    NvS32 status;
-} nv_ioctl_set_numa_status_t;
-
-#define NV_IOCTL_NUMA_STATUS_DISABLED               0
-#define NV_IOCTL_NUMA_STATUS_OFFLINE                1
-#define NV_IOCTL_NUMA_STATUS_ONLINE_IN_PROGRESS     2
-#define NV_IOCTL_NUMA_STATUS_ONLINE                 3
-#define NV_IOCTL_NUMA_STATUS_ONLINE_FAILED          4
-#define NV_IOCTL_NUMA_STATUS_OFFLINE_IN_PROGRESS    5
-#define NV_IOCTL_NUMA_STATUS_OFFLINE_FAILED         6
-
 #ifdef NVRM
 
 extern const char *pNVRM_ID;
@@ -329,49 +290,23 @@ typedef struct nv_event_s
     struct nv_event_s  *next;
 } nv_event_t;
 
-/*
- * this is to be able to associate a fd memdesc to a file descriptor
- */
-typedef struct nv_fd_memdesc_s
-{
-    NvBool              bValid;
-    NvHandle            hParent;
-    NvHandle            hMemory;
-} nv_fd_memdesc_t;
-
 typedef struct nv_kern_mapping_s
 {
     void  *addr;
     NvU64 size;
-    NvU32 modeFlag;
     struct nv_kern_mapping_s *next;
 } nv_kern_mapping_t;
 
-typedef struct nv_usermap_access_params_s
+typedef struct nv_mmap_context_s
 {
-    NvU64 addr;
+    NvP64 addr;
     NvU64 size;
-    NvU64 mmap_start;
-    NvU64 mmap_size;
-    NvU64 access_start;
-    NvU64 access_size;
-    NvU64 remap_prot_extra;
-} nv_usermap_access_params_t;
-
-/*
- * It stores mapping context per mapping
- */
-typedef struct nv_alloc_mapping_context_s {
-    void  *alloc;
-    NvU64  page_index;
-    NvU64 mmap_start;
-    NvU64 mmap_size;
-    NvU64 access_start;
-    NvU64 access_size;
-    NvU64 remap_prot_extra;
-    NvU32  prot;
-    NvBool bValid;
-} nv_alloc_mapping_context_t;
+    NvU32 process_id;
+    NvU32 thread_id;
+    void *file;
+    void *os_priv;
+    struct nv_mmap_context_s *next;
+} nv_mmap_context_t;
 
 /*
  * per device state
@@ -389,7 +324,6 @@ typedef struct
     NvU16 subsystem_id;
     NvU16 subsystem_vendor;
     NvU32 gpu_id;
-    NvU32 iovaspace_id;
     struct
     {
         NvBool         bValid;
@@ -415,51 +349,37 @@ typedef struct
     /* list of events allocated for this device */
     nv_event_t *event_list;
 
-    /* lock to protect event_list */
-    void *event_spinlock;
-
     nv_kern_mapping_t *kern_mappings;
 
+    nv_mmap_context_t *mmap_contexts;
+ 
     /* DMA addressable range of the device */
     NvU64 dma_addressable_start;
     NvU64 dma_addressable_limit;
-
-    NvBool nvlink_sysmem_links_enabled;
 } nv_state_t;
 
 // Forward define the gpu ops structures
-typedef struct gpuSession                           *nvgpuSessionHandle_t;
-typedef struct gpuAddressSpace                      *nvgpuAddressSpaceHandle_t;
-typedef struct gpuChannel                           *nvgpuChannelHandle_t;
-typedef struct gpuObject                            *nvgpuObjectHandle_t;
-typedef struct UvmGpuChannelPointers_tag            *nvgpuChannelInfo_t;
-typedef struct UvmGpuChannelAllocParams_tag          nvgpuChannelAllocParams_t;
-typedef struct UvmGpuCaps_tag                       *nvgpuCaps_t;
-typedef struct UvmGpuAddressSpaceInfo_tag           *nvgpuAddressSpaceInfo_t;
-typedef struct UvmGpuAllocInfo_tag                  *nvgpuAllocInfo_t;
-typedef struct UvmGpuP2PCapsParams_tag              *nvgpuP2PCapsParams_t;
-typedef struct gpuVaAllocInfo                       *nvgpuVaAllocInfo_t;
-typedef struct gpuMapInfo                           *nvgpuMapInfo_t;
-typedef struct UvmGpuFbInfo_tag                     *nvgpuFbInfo_t;
-typedef struct UvmGpuFaultInfo_tag                  *nvgpuFaultInfo_t;
-typedef struct UvmGpuAccessCntrInfo_tag             *nvgpuAccessCntrInfo_t;
-typedef struct UvmGpuAccessCntrConfig_tag           *nvgpuAccessCntrConfig_t;
-typedef struct UvmGpuInfo_tag                       *nvgpuInfo_t;
-typedef struct gpuPmaAllocationOptions              *nvgpuPmaAllocationOptions_t;
-typedef struct UvmGpuMemoryInfo_tag                 *nvgpuMemoryInfo_t;
-typedef struct UvmGpuExternalMappingInfo_tag        *nvgpuExternalMappingInfo_t;
-typedef struct UvmGpuChannelResourceInfo_tag        *nvgpuChannelResourceInfo_t;
-typedef struct UvmGpuChannelInstanceInfo_tag        *nvgpuChannelInstanceInfo_t;
-typedef struct UvmGpuChannelResourceBindParams_tag  *nvgpuChannelResourceBindParams_t;
-typedef NV_STATUS (*nvPmaEvictPagesCallback)(void *, NvU32, NvU64 *, NvU32, NvU64, NvU64);
-typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
+typedef struct gpuSession           *nvgpuSessionHandle_t;
+typedef struct gpuAddressSpace      *nvgpuAddressSpaceHandle_t;
+typedef struct gpuChannel           *nvgpuChannelHandle_t;
+typedef struct gpuObject            *nvgpuObjectHandle_t;
+typedef struct gpuChannelInfo       *nvgpuChannelInfo_t;
+typedef struct gpuCaps              *nvgpuCaps_t;
+typedef struct gpuAllocInfo         *nvgpuAllocInfo_t;
+typedef struct gpuVaAllocInfo       *nvgpuVaAllocInfo_t;
+typedef struct gpuMapInfo           *nvgpuMapInfo_t;
+typedef struct gpuFbInfo            *nvgpuFbInfo_t;
+typedef struct gpuFaultInfo         *nvgpuFaultInfo_t;
+typedef struct gpuInfo              *nvgpuInfo_t;
+typedef struct gpuPageLevelInfo     *nvgpuPageLevelInfo_t;
+typedef struct gpuChannelPhysInfo   *nvgpuChannelPhysInfo_t;
 
 /*
  * flags
  */
 
 #define NV_FLAG_OPEN                   0x0001
-// EMPTY SLOT                          0x0002
+#define NV_FLAG_WAS_POSTED             0x0002
 #define NV_FLAG_CONTROL                0x0004
 #define NV_FLAG_MAP_REGS_EARLY         0x0008
 #define NV_FLAG_USE_BAR0_CFG           0x0010
@@ -480,28 +400,27 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 
 #define NV_PRIMARY_VGA(nv)      ((nv)->primary_vga)
 
-#define NV_IS_GVI_DEVICE(nv)    ((nv)->flags & NV_FLAG_GVI)
-#define NV_IS_CTL_DEVICE(nv)    ((nv)->flags & NV_FLAG_CONTROL)
+#define NV_IS_GVI_DEVICE(nv) ((nv)->flags & NV_FLAG_GVI)
 
-/*
- * The ACPI specification defines IDs for various ACPI video
- * extension events like display switch events, AC/battery
- * events, docking events, etc..
- * Whenever an ACPI event is received by the corresponding
- * event handler installed within the core NVIDIA driver, the
- * code can verify the event ID before processing it.
+/*                                                                                    
+ * The ACPI specification defines IDs for various ACPI video                          
+ * extension events like display switch events, AC/battery                            
+ * events, docking events, etc..                                                      
+ * Whenever an ACPI event is received by the corresponding                            
+ * event handler installed within the core NVIDIA driver, the                         
+ * code can verify the event ID before processing it.                                 
  */
-#define ACPI_DISPLAY_DEVICE_CHANGE_EVENT      0x80
+#define ACPI_DISPLAY_DEVICE_CHANGE_EVENT      0x80 
 #define NVIF_NOTIFY_DISPLAY_DETECT           0xCB
-#define NVIF_DISPLAY_DEVICE_CHANGE_EVENT     NVIF_NOTIFY_DISPLAY_DETECT
-/*
- * NVIDIA ACPI event IDs to be passed into the core NVIDIA
- * driver for various events like display switch events,
- * AC/battery events, docking events, etc..
- */
-#define NV_SYSTEM_ACPI_DISPLAY_SWITCH_EVENT  0x8001
-#define NV_SYSTEM_ACPI_BATTERY_POWER_EVENT   0x8002
-#define NV_SYSTEM_ACPI_DOCK_EVENT            0x8003
+#define NVIF_DISPLAY_DEVICE_CHANGE_EVENT     NVIF_NOTIFY_DISPLAY_DETECT 
+/*                                                                                    
+ * NVIDIA ACPI event IDs to be passed into the core NVIDIA                            
+ * driver for various events like display switch events,                              
+ * AC/battery events, docking events, etc..                                           
+ */                                                                                   
+#define NV_SYSTEM_ACPI_DISPLAY_SWITCH_EVENT  0x8001                                   
+#define NV_SYSTEM_ACPI_BATTERY_POWER_EVENT   0x8002                                   
+#define NV_SYSTEM_ACPI_DOCK_EVENT            0x8003                                   
 
 /*
  * Status bit definitions for display switch hotkey events.
@@ -511,15 +430,15 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 #define NV_HOTKEY_STATUS_DISPLAY_ENABLE_TV  0x04
 #define NV_HOTKEY_STATUS_DISPLAY_ENABLE_DFP 0x08
 
-/*
- * NVIDIA ACPI sub-event IDs (event types) to be passed into
- * to core NVIDIA driver for ACPI events.
- */
-#define NV_SYSTEM_ACPI_EVENT_VALUE_DISPLAY_SWITCH_DEFAULT    0
-#define NV_SYSTEM_ACPI_EVENT_VALUE_POWER_EVENT_AC            0
-#define NV_SYSTEM_ACPI_EVENT_VALUE_POWER_EVENT_BATTERY       1
-#define NV_SYSTEM_ACPI_EVENT_VALUE_DOCK_EVENT_UNDOCKED       0
-#define NV_SYSTEM_ACPI_EVENT_VALUE_DOCK_EVENT_DOCKED         1
+/*                                                                                    
+ * NVIDIA ACPI sub-event IDs (event types) to be passed into                          
+ * to core NVIDIA driver for ACPI events.                                             
+ */                                                                                   
+#define NV_SYSTEM_ACPI_EVENT_VALUE_DISPLAY_SWITCH_DEFAULT    0                        
+#define NV_SYSTEM_ACPI_EVENT_VALUE_POWER_EVENT_AC            0                        
+#define NV_SYSTEM_ACPI_EVENT_VALUE_POWER_EVENT_BATTERY       1                        
+#define NV_SYSTEM_ACPI_EVENT_VALUE_DOCK_EVENT_UNDOCKED       0                        
+#define NV_SYSTEM_ACPI_EVENT_VALUE_DOCK_EVENT_DOCKED         1                        
 
 #define NV_ACPI_NVIF_HANDLE_PRESENT 0x01
 #define NV_ACPI_DSM_HANDLE_PRESENT  0x02
@@ -541,11 +460,6 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 #define NV_I2C_CMD_SMBUS_BLOCK_READ  7
 #define NV_I2C_CMD_SMBUS_BLOCK_WRITE 8
 
-// Flags needed by OSAllocPagesNode
-#define NV_ALLOC_PAGES_NODE_NONE                0x0
-#define NV_ALLOC_PAGES_NODE_SCRUB_ON_ALLOC      0x1
-#define NV_ALLOC_PAGES_NODE_FORCE_ALLOC         0x2
-
 /*
 ** where we hide our nv_state_t * ...
 */
@@ -612,8 +526,6 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
         }                                                                   \
     }
 
-#define NV_TIMEVAL_TO_US(tv)    ((NvU64)(tv).tv_sec * 1000000 + (tv).tv_usec)
-
 #ifndef NV_ALIGN_UP
 #define NV_ALIGN_UP(v,g) (((v) + ((g) - 1)) & ~((g) - 1))
 #endif
@@ -653,16 +565,16 @@ typedef NV_STATUS (*nvPmaEvictRangeCallback)(void *, NvU64, NvU64);
 #endif
 #endif /* !defined(NV_API_CALL) */
 
+
 void*      NV_API_CALL  nv_alloc_kernel_mapping  (nv_state_t *, void *, NvU64, NvU32, NvU64, void **);
 NV_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, void *);
 NV_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, void *, NvU64, NvU32, NvU64, NvU32, NvU64 *, void **);
 NV_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, NvU64, void *);
-NV_STATUS  NV_API_CALL  nv_add_mapping_context_to_file (nv_state_t *, nv_usermap_access_params_t*, NvU32, void *, NvU64, NvU32);
+NV_STATUS  NV_API_CALL  nv_create_user_mapping_context (nv_state_t *, NvU64, NvU64, void **);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
-nv_state_t*  NV_API_CALL  nv_get_adapter_state   (NvU32, NvU8, NvU8);
-nv_state_t*  NV_API_CALL  nv_get_ctl_state       (void);
+void*  NV_API_CALL  nv_get_adapter_state         (NvU32, NvU8, NvU8);
 
 void   NV_API_CALL  nv_set_dma_address_size      (nv_state_t *, NvU32 );
 
@@ -673,20 +585,14 @@ NV_STATUS  NV_API_CALL  nv_free_pages            (nv_state_t *, NvU32, NvBool, N
 NV_STATUS  NV_API_CALL  nv_register_user_pages   (nv_state_t *, NvU64, NvU64 *, void **);
 NV_STATUS  NV_API_CALL  nv_unregister_user_pages (nv_state_t *, NvU64, void **);
 
-NV_STATUS NV_API_CALL   nv_register_peer_io_mem   (nv_state_t *, NvU64 *, NvU64, void **);
-void      NV_API_CALL   nv_unregister_peer_io_mem (nv_state_t *, void *);
-
 NV_STATUS  NV_API_CALL  nv_dma_map_pages         (nv_state_t *, NvU64, NvU64 *, NvBool, void **);
 NV_STATUS  NV_API_CALL  nv_dma_unmap_pages       (nv_state_t *, NvU64, NvU64 *, void **);
 
-NV_STATUS  NV_API_CALL  nv_dma_map_alloc         (nv_state_t *, NvU64, NvU64 *, NvBool, void **);
+NV_STATUS  NV_API_CALL  nv_dma_map_alloc         (nv_state_t *, NvU64, NvU64 *, void **);
 NV_STATUS  NV_API_CALL  nv_dma_unmap_alloc       (nv_state_t *, NvU64, NvU64 *, void **);
 
-NV_STATUS  NV_API_CALL  nv_dma_map_peer          (nv_state_t *, nv_state_t *, NvU8, NvU64, NvU64 *);
-void       NV_API_CALL  nv_dma_unmap_peer        (nv_state_t *, NvU64, NvU64);
-
-NV_STATUS  NV_API_CALL  nv_dma_map_mmio          (nv_state_t *, NvU64, NvU64 *);
-void       NV_API_CALL  nv_dma_unmap_mmio        (nv_state_t *, NvU64, NvU64);
+NV_STATUS  NV_API_CALL  nv_dma_map_peer          (nv_state_t *, nv_aperture_t *, NvU64, NvU64 *);
+NV_STATUS  NV_API_CALL  nv_dma_unmap_peer        (nv_state_t *, NvU64, NvU64 *);
 
 NvS32  NV_API_CALL  nv_start_rc_timer            (nv_state_t *);
 NvS32  NV_API_CALL  nv_stop_rc_timer             (nv_state_t *);
@@ -694,6 +600,8 @@ NvS32  NV_API_CALL  nv_stop_rc_timer             (nv_state_t *);
 void   NV_API_CALL  nv_post_event                (nv_state_t *, nv_event_t *, NvHandle, NvU32, NvBool);
 NvS32  NV_API_CALL  nv_get_event                 (nv_state_t *, void *, nv_event_t *, NvU32 *);
 
+NvS32  NV_API_CALL  nv_no_incoherent_mappings    (void);
+
 void   NV_API_CALL  nv_verify_pci_config         (nv_state_t *, BOOL);
 
 void*  NV_API_CALL  nv_i2c_add_adapter           (nv_state_t *, NvU32);
@@ -709,6 +617,7 @@ NV_STATUS  NV_API_CALL  nv_acpi_dod_method       (nv_state_t *, NvU32 *, NvU32 *
 NV_STATUS  NV_API_CALL  nv_acpi_rom_method       (nv_state_t *, NvU32 *, NvU32 *);
 NV_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const char *, va_list);
 
+NV_STATUS  NV_API_CALL  nv_alloc_os_descriptor_handle (nv_state_t *, NvS32, void *, NvU64, NvU32 *);
 NvU64      NV_API_CALL  nv_get_dma_start_address (nv_state_t *);
 NV_STATUS  NV_API_CALL  nv_set_primary_vga_status(nv_state_t *);
 NV_STATUS  NV_API_CALL  nv_pci_trigger_recovery  (nv_state_t *);
@@ -718,23 +627,6 @@ NvBool     NV_API_CALL  nv_requires_dma_remap    (nv_state_t *);
 NvBool     NV_API_CALL  nv_is_virtualized_system  (nv_stack_t *);
 #endif
 
-nv_fd_memdesc_t* NV_API_CALL nv_get_fd_memdesc   (void *);
-NV_STATUS  NV_API_CALL  nv_add_fd_memdesc_to_fd  (NvU32, const nv_fd_memdesc_t*);
-
-NV_STATUS NV_API_CALL nv_export_rm_object_to_fd    (NvHandle, NvS32);
-NV_STATUS NV_API_CALL nv_import_rm_object_from_fd  (NvS32, NvHandle *);
-
-NV_STATUS NV_API_CALL nv_get_device_memory_config(nv_state_t *, NvU32 *, NvU32 *, NvU32 *, NvU32 *, NvS32 *);
-
-NV_STATUS NV_API_CALL nv_get_ibmnpu_genreg_info(nv_state_t *, NvU64 *, NvU64 *);
-NV_STATUS NV_API_CALL nv_get_ibmnpu_relaxed_ordering_mode(nv_state_t *nv, NvBool *mode);
-
-#if defined(NVCPU_PPC64LE)
-NV_STATUS NV_API_CALL nv_get_nvlink_line_rate    (nv_state_t *, NvU32 *);
-#endif
-
-void      NV_API_CALL nv_register_backlight      (nv_state_t *, NvU32, NvU32);
-void      NV_API_CALL nv_unregister_backlight    (nv_state_t *);
 /*
  * ---------------------------------------------------------------------------
  *
@@ -750,13 +642,14 @@ BOOL       NV_API_CALL  rm_free_private_state    (nvidia_stack_t *, nv_state_t *
 BOOL       NV_API_CALL  rm_init_adapter          (nvidia_stack_t *, nv_state_t *);
 BOOL       NV_API_CALL  rm_disable_adapter       (nvidia_stack_t *, nv_state_t *);
 BOOL       NV_API_CALL  rm_shutdown_adapter      (nvidia_stack_t *, nv_state_t *);
+NV_STATUS  NV_API_CALL  rm_extract_mmap_context  (nvidia_stack_t *, nv_state_t *, NvP64, NvU64, void **);
+void       NV_API_CALL  rm_purge_mmap_contexts   (nvidia_stack_t *, nv_state_t *, void *);
 NV_STATUS  NV_API_CALL  rm_validate_mmap_request (nvidia_stack_t *, nv_state_t *, void *, NvU64, NvU64, NvU32 *, void **, NvU64 *);
 NV_STATUS  NV_API_CALL  rm_acquire_api_lock      (nvidia_stack_t *);
 NV_STATUS  NV_API_CALL  rm_release_api_lock      (nvidia_stack_t *);
 NV_STATUS  NV_API_CALL  rm_ioctl                 (nvidia_stack_t *, nv_state_t *, void *, NvU32, void *, NvU32);
 BOOL       NV_API_CALL  rm_isr                   (nvidia_stack_t *, nv_state_t *, NvU32 *);
 void       NV_API_CALL  rm_isr_bh                (nvidia_stack_t *, nv_state_t *);
-void       NV_API_CALL  rm_isr_bh_unlocked       (nvidia_stack_t *, nv_state_t *);
 NV_STATUS  NV_API_CALL  rm_power_management      (nvidia_stack_t *, nv_state_t *, NvU32, NvU32);
 NV_STATUS  NV_API_CALL  rm_save_low_res_mode     (nvidia_stack_t *, nv_state_t *);
 NV_STATUS  NV_API_CALL  rm_get_vbios_version     (nvidia_stack_t *, nv_state_t *, NvU32 *, NvU32 *, NvU32 *, NvU32 *, NvU32 *);
@@ -764,15 +657,12 @@ NV_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nvidia_stack_t *, nv_state_t *
 NV_STATUS  NV_API_CALL  rm_get_gpu_uuid_raw      (nvidia_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 void       NV_API_CALL  rm_free_unused_clients   (nvidia_stack_t *, nv_state_t *, void *);
 void       NV_API_CALL  rm_unbind_lock           (nvidia_stack_t *, nv_state_t *);
-void       NV_API_CALL  rm_free_exported_object  (nvidia_stack_t *, NvHandle);
+
 NV_STATUS  NV_API_CALL  rm_read_registry_dword   (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32 *);
 NV_STATUS  NV_API_CALL  rm_write_registry_dword  (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32);
 NV_STATUS  NV_API_CALL  rm_read_registry_binary  (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32 *);
 NV_STATUS  NV_API_CALL  rm_write_registry_binary (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU8 *, NvU32);
 NV_STATUS  NV_API_CALL  rm_write_registry_string (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU8 *, const char *, NvU32);
-void       NV_API_CALL  rm_parse_option_string   (nvidia_stack_t *, const char *);
-char*      NV_API_CALL  rm_remove_spaces         (const char *);
-char*      NV_API_CALL  rm_string_token          (char **, const char);
 
 NV_STATUS  NV_API_CALL  rm_run_rc_callback       (nvidia_stack_t *, nv_state_t *);
 void       NV_API_CALL  rm_execute_work_item     (nvidia_stack_t *, void *);
@@ -784,7 +674,9 @@ void       NV_API_CALL  rm_register_compatible_ioctls   (nvidia_stack_t *);
 void       NV_API_CALL  rm_unregister_compatible_ioctls (nvidia_stack_t *);
 
 BOOL       NV_API_CALL  rm_is_legacy_device      (nvidia_stack_t *, NvU16, NvU16, NvU16, BOOL);
-NV_STATUS  NV_API_CALL  rm_is_supported_device   (nvidia_stack_t *, nv_state_t *);
+BOOL       NV_API_CALL  rm_is_legacy_arch        (NvU32, NvU32);
+NV_STATUS  NV_API_CALL  rm_is_supported_device   (nvidia_stack_t *, nv_state_t *, NvU32 *, NvU32 *);
+
 
 void       NV_API_CALL  rm_check_pci_config_space (nvidia_stack_t *, nv_state_t *nv, BOOL, BOOL, BOOL);
 
@@ -799,95 +691,49 @@ NV_STATUS  NV_API_CALL  rm_system_event           (nvidia_stack_t *, NvU32, NvU3
 void       NV_API_CALL  rm_disable_gpu_state_persistence    (nvidia_stack_t *sp, nv_state_t *);
 NV_STATUS  NV_API_CALL  rm_p2p_init_mapping       (nvidia_stack_t *, NvU64, NvU64 *, NvU64 *, NvU64 *, NvU64 *, NvU64, NvU64, NvU64, NvU64, void (*)(void *), void *);
 NV_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nvidia_stack_t *, NvU64);
-NV_STATUS  NV_API_CALL  rm_p2p_get_pages          (nvidia_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 *, NvU32 *, NvU32 *, NvU32 *, NvU8 **, void *, void (*)(void *), void *);
+NV_STATUS  NV_API_CALL  rm_p2p_get_pages          (nvidia_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 *, NvU32 *, NvU32 *, NvU32 *, void *, void (*)(void *), void *);
 NV_STATUS  NV_API_CALL  rm_p2p_put_pages          (nvidia_stack_t *, NvU64, NvU32, NvU64, void *);
-NV_STATUS  NV_API_CALL  rm_p2p_dma_map_pages      (nvidia_stack_t *, nv_state_t *, NvU8 *, NvU32, NvU32, NvU64 *, void **);
-NV_STATUS  NV_API_CALL  rm_p2p_dma_unmap_pages    (nvidia_stack_t *, nv_state_t *, NvU32, NvU32, NvU64 *, void *);
 NV_STATUS  NV_API_CALL  rm_get_cpu_type           (nvidia_stack_t *, nv_cpu_type_t *);
 NV_STATUS  NV_API_CALL  rm_log_gpu_crash          (nv_stack_t *, nv_state_t *);
 
 NV_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nvidia_stack_t *, nvgpuSessionHandle_t *);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nvidia_stack_t *, nvgpuSessionHandle_t);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create(nvidia_stack_t *, nvgpuSessionHandle_t, const NvProcessorUuid *, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *, nvgpuAddressSpaceInfo_t);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_dup_address_space(nvidia_stack_t *, nvgpuSessionHandle_t, const NvProcessorUuid *, NvHandle, NvHandle, nvgpuAddressSpaceHandle_t *, nvgpuAddressSpaceInfo_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create(nvidia_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *, unsigned long long, unsigned long long);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create_mirrored(nvidia_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_address_space_destroy(nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_fb(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
-
-NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_alloc_pages(nvidia_stack_t *, void *, NvLength, NvU32 , nvgpuPmaAllocationOptions_t, NvU64 *);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_free_pages(nvidia_stack_t *, void *, NvU64 *, NvLength , NvU32, NvU32);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_pin_pages(nvidia_stack_t *, void *, NvU64 *, NvLength , NvU32, NvU32);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_unpin_pages(nvidia_stack_t *, void *, NvU64 *, NvLength , NvU32);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_get_pma_object(nvidia_stack_t *, const NvProcessorUuid *, void **);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_pma_register_callbacks(nvidia_stack_t *sp, void *, nvPmaEvictPagesCallback, nvPmaEvictRangeCallback, void *);
-void       NV_API_CALL  rm_gpu_ops_pma_unregister_callbacks(nvidia_stack_t *sp, void *);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_gpu_va(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuVaAllocInfo_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_gpu_pa(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
 
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_sys(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *, nvgpuAllocInfo_t);
-
-NV_STATUS  NV_API_CALL  rm_gpu_ops_get_p2p_caps(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAddressSpaceHandle_t, nvgpuP2PCapsParams_t);
-
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_map(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, NvLength, void **, NvU32);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_ummap(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, void*);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_channel_allocate(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuChannelHandle_t *, const nvgpuChannelAllocParams_t *, nvgpuChannelInfo_t);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_channel_allocate(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuChannelHandle_t *, nvgpuChannelInfo_t);
 NV_STATUS  NV_API_CALL  rm_gpu_ops_channel_destroy(nvidia_stack_t *, nvgpuChannelHandle_t);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_copy_engine_alloc(nvidia_stack_t *, nvgpuChannelHandle_t, NvU32, nvgpuObjectHandle_t *, nvgpuChannelInfo_t);
+const char*  NV_API_CALL  rm_gpu_ops_channel_translate_error(nvidia_stack_t *, NvU32);
+NV_STATUS  NV_API_CALL  rm_gpu_ops_copy_engine_allocate(nvidia_stack_t *, nvgpuChannelHandle_t, NvU32, NvU32*, nvgpuObjectHandle_t *);
 NV_STATUS  NV_API_CALL rm_gpu_ops_memory_free(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
+NV_STATUS  NV_API_CALL rm_gpu_ops_memory_free_va(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
+NV_STATUS  NV_API_CALL rm_gpu_ops_memory_free_pa(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
 NV_STATUS  NV_API_CALL rm_gpu_ops_query_caps(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuCaps_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_info(nvidia_stack_t *, const NvProcessorUuid *pUuid, nvgpuInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_service_device_interrupts_rm(nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_attached_uuids(nvidia_stack_t *, NvU8 *pUuidList, unsigned *numGpus);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_info(nvidia_stack_t *, NvU8 *pUuid, unsigned uuidLength, nvgpuInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_uvm_priv_region(NvU64 *pPrivRegionStart, NvU64 *pPrivRegionLength);
+NV_STATUS  NV_API_CALL rm_gpu_ops_service_device_interrupts_rm(nvidia_stack_t *, nvgpuChannelHandle_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_check_ecc_error_slowpath(nvidia_stack_t *, nvgpuChannelHandle_t, NvBool *);
+NV_STATUS  NV_API_CALL rm_gpu_ops_kill_channel(nvidia_stack_t *, nvgpuChannelHandle_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_gmmu_fmt(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, void **);
 NV_STATUS  NV_API_CALL rm_gpu_ops_dup_allocation(nvidia_stack_t *, NvHandle, nvgpuAddressSpaceHandle_t, NvU64, nvgpuAddressSpaceHandle_t, NvU64*, NvBool);
-
-NV_STATUS  NV_API_CALL  rm_gpu_ops_dup_memory (nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, NvHandle *, nvgpuMemoryInfo_t);
-
 NV_STATUS  NV_API_CALL rm_gpu_ops_free_duped_handle(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle);
 NV_STATUS  NV_API_CALL rm_gpu_ops_get_fb_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFbInfo_t);
-NV_STATUS NV_API_CALL rm_gpu_ops_own_page_fault_intr(nvidia_stack_t *, const NvProcessorUuid *, NvBool);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_gpu_ids(nvidia_stack_t *sp, NvU8 *pUuid, unsigned uuidLength, NvU32 *pDeviceId, NvU32 *pSubdeviceId);
 NV_STATUS  NV_API_CALL rm_gpu_ops_init_fault_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFaultInfo_t);
 NV_STATUS  NV_API_CALL rm_gpu_ops_destroy_fault_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuFaultInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_get_non_replayable_faults(nvidia_stack_t *, nvgpuFaultInfo_t, void *, NvU32 *);
-NV_STATUS  NV_API_CALL rm_gpu_ops_has_pending_non_replayable_faults(nvidia_stack_t *, nvgpuFaultInfo_t, NvBool *);
-NV_STATUS  NV_API_CALL rm_gpu_ops_init_access_cntr_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAccessCntrInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_destroy_access_cntr_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAccessCntrInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_own_access_cntr_intr(nvidia_stack_t *, nvgpuSessionHandle_t, nvgpuAccessCntrInfo_t, NvBool);
-NV_STATUS  NV_API_CALL rm_gpu_ops_enable_access_cntr(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAccessCntrInfo_t, nvgpuAccessCntrConfig_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_disable_access_cntr(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAccessCntrInfo_t);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_set_page_directory (nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, unsigned, NvBool);
-NV_STATUS  NV_API_CALL  rm_gpu_ops_unset_page_directory (nvidia_stack_t *, nvgpuAddressSpaceHandle_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_p2p_object_create(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuAddressSpaceHandle_t, NvHandle *);
-void       NV_API_CALL rm_gpu_ops_p2p_object_destroy(nvidia_stack_t *, nvgpuSessionHandle_t, NvHandle);
-NV_STATUS  NV_API_CALL rm_gpu_ops_get_external_alloc_ptes(nvidia_stack_t*, nvgpuAddressSpaceHandle_t, NvHandle, NvU64, NvU64, nvgpuExternalMappingInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvHandle, NvHandle, void **, nvgpuChannelInstanceInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_retain_channel_resources(nvidia_stack_t *, void *, nvgpuChannelResourceInfo_t);
-NV_STATUS  NV_API_CALL rm_gpu_ops_bind_channel_resources(nvidia_stack_t *, void *, nvgpuChannelResourceBindParams_t);
-void       NV_API_CALL rm_gpu_ops_release_channel(nvidia_stack_t *, void *);
-void       NV_API_CALL rm_gpu_ops_release_channel_resources(nvidia_stack_t *, NvP64*, NvU32);
-void       NV_API_CALL rm_gpu_ops_stop_channel(nvidia_stack_t *, void *, NvBool);
-NV_STATUS  NV_API_CALL rm_gpu_ops_get_channel_resource_ptes(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvP64, NvU64, NvU64, nvgpuExternalMappingInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_page_level_info(nvidia_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, nvgpuPageLevelInfo_t);
+NV_STATUS  NV_API_CALL rm_gpu_ops_get_channel_phys_info(nvidia_stack_t *, NvHandle, NvHandle, nvgpuChannelPhysInfo_t);
+
 void       NV_API_CALL rm_kernel_rmapi_op(nvidia_stack_t *sp, void *ops_cmd);
-NvBool     NV_API_CALL rm_get_device_remove_flag(nvidia_stack_t *sp, NvU32 gpu_id);
-NV_STATUS  NV_API_CALL rm_gpu_copy_mmu_faults(nvidia_stack_t *, nv_state_t *, NvU32 *);
-NV_STATUS  NV_API_CALL rm_gpu_copy_mmu_faults_unlocked(nvidia_stack_t *, nv_state_t *, NvU32 *);
-NV_STATUS  NV_API_CALL rm_gpu_need_4k_page_isolation(nv_state_t *, NvBool *);
-NvBool     NV_API_CALL rm_is_chipset_io_coherent(nv_stack_t *);
-NvBool     NV_API_CALL rm_init_event_locks(nvidia_stack_t *, nv_state_t *);
-void       NV_API_CALL rm_destroy_event_locks(nvidia_stack_t *, nv_state_t *);
-void       NV_API_CALL rm_get_gpu_numa_info(nvidia_stack_t *, nv_state_t *, NvS32 *, NvU64 *, NvU64 *);
-NV_STATUS  NV_API_CALL rm_set_backlight(nvidia_stack_t *, nv_state_t *, NvU32, NvU32);
-NV_STATUS  NV_API_CALL rm_get_backlight(nvidia_stack_t *, nv_state_t *, NvU32, NvU32 *);
-NV_STATUS  NV_API_CALL rm_gpu_numa_online(nvidia_stack_t *, nv_state_t *);
-NV_STATUS  NV_API_CALL rm_gpu_numa_offline(nvidia_stack_t *, nv_state_t *);
 
-/* vGPU VFIO specific functions */
-NV_STATUS  NV_API_CALL  nv_vgpu_create_request(nvidia_stack_t *, nv_state_t *, NvU8 *, NvU32, NvU16 *);
-NV_STATUS  NV_API_CALL  nv_vgpu_delete(nvidia_stack_t *, NvU8 *, NvU16);
-NV_STATUS  NV_API_CALL  nv_vgpu_get_type_ids(nvidia_stack_t *, nv_state_t *, NvU32 *, NvU32 **);
-NV_STATUS  NV_API_CALL  nv_vgpu_get_type_info(nvidia_stack_t *, nv_state_t *, NvU32, NvU8 *, int);
-NV_STATUS  NV_API_CALL  nv_vgpu_get_bar_info(nvidia_stack_t *, nv_state_t *, NvU8 *, NvU64 *, NvU32, void *, void **);
-NV_STATUS  NV_API_CALL  nv_vgpu_start(nvidia_stack_t *, NvU8 *, void *, NvS32 *, NvU8 *, NvU32, NvU8 *);
-NV_STATUS  NV_API_CALL  nv_vgpu_get_sparse_mmap(nvidia_stack_t *, nv_state_t *, NvU8 *, NvU64 **, NvU64 **, NvU32 *);
-NV_STATUS  NV_API_CALL  nv_vgpu_update_request(nvidia_stack_t *, NvU8 *);
-NV_STATUS  NV_API_CALL  nv_gpu_bind_event(nvidia_stack_t *);
-
-NV_STATUS NV_API_CALL nv_get_usermap_access_params(nv_state_t*, nv_usermap_access_params_t*);
 #endif /* NVWATCH */
 
 #endif /* NVRM */
