@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2017 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2014 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -26,7 +26,7 @@ nv_state_t nvidia_ctl_state;
 int nvidia_attach(device_t dev)
 {
     NV_STATUS status;
-    NvU32 i;
+    NvU32 i, pmc_boot_0, pmc_boot_42;
     struct nvidia_softc *sc;
     nv_state_t *nv;
 
@@ -55,8 +55,24 @@ int nvidia_attach(device_t dev)
 
     pci_enable_io(dev, SYS_RES_MEMORY);
 
-    if ((rm_is_supported_device(sc->attach_sp, nv)) != NV_OK)
+    if ((status = rm_is_supported_device(sc->attach_sp, nv, &pmc_boot_0,
+                                         &pmc_boot_42)) != NV_OK)
+    {
+        if ((status != NV_ERR_NOT_SUPPORTED) ||
+            !rm_is_legacy_arch(pmc_boot_0, pmc_boot_42))
+        {
+            nv_printf(NV_DBG_ERRORS,
+                "NVRM: The NVIDIA GPU %02x:%02x (PCI ID: %04x:%04x) installed\n"
+                "NVRM: in this system is not supported by the %s NVIDIA FreeBSD\n"
+                "NVRM: graphics driver release.  Please see 'Appendix A -\n"
+                "NVRM: Supported NVIDIA GPU Products' in this release's README,\n"
+                "NVRM: available on the FreeBSD graphics driver download page at\n"
+                "NVRM: www.nvidia.com.\n",
+                nv->pci_info.bus, nv->pci_info.slot, nv->pci_info.vendor_id, 
+                nv->pci_info.device_id, NV_VERSION_STRING);
+        }
         return ENXIO;
+    }
 
     for (i = 0; i < NV_GPU_NUM_BARS; i++) {
         if (sc->BAR_recs[i] != NULL) {
@@ -172,8 +188,6 @@ int nvidia_suspend(device_t dev)
     sc = device_get_softc(dev);
     nv = sc->nv_state;
 
-    nvidia_modeset_suspend(nv->gpu_id);
-
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, TRUE);
     status = rm_power_management(sp, nv, 0, NV_PM_ACPI_STANDBY);
 
@@ -205,11 +219,6 @@ int nvidia_resume(device_t dev)
 
     NV_UMA_ZONE_FREE_STACK(sp);
 
-    if (status == NV_OK)
-    {
-        nvidia_modeset_resume(nv->gpu_id);
-    }
-
     return (status == NV_OK) ? 0 : EIO;
 }
 #endif /* NV_SUPPORT_ACPI_PM */
@@ -297,7 +306,6 @@ void nvidia_intr(void *xsc)
     nv_state_t *nv;
     NvU32 run_bottom_half = 0;
     nvidia_stack_t *sp;
-    NvU32 faultsCopied = 0;
 
     sc = (struct nvidia_softc *) xsc;
     nv = sc->nv_state;
@@ -311,14 +319,6 @@ void nvidia_intr(void *xsc)
     rm_isr(sp, nv, &run_bottom_half);
 
     if (run_bottom_half) {
-        /* 
-         * As UVM with faulting is currently not supported in this plateform, we can copy
-         * MMU faults after grabbing RM lock. With UVM, this routine should be called
-         * before calling rm_isr and bottom_half should be scheduled unconditionally
-         * with low priority thread as bottom_half can wait for lock
-         */
-        rm_gpu_copy_mmu_faults(sp, nv, &faultsCopied);
-
         /* We're not executing in an HW ISR context */
         rm_isr_bh(sp, nv);
     }
@@ -524,25 +524,6 @@ static int nv_dev_alloc_stacks(nvidia_softc_t *sc)
     return 0;
 }
 
-static nv_state_t *nvidia_find_state(NvU32 gpu_id)
-{
-    unsigned int i;
-    for (i = 0; i < NV_MAX_DEVICES; i++) {
-        nv_state_t *nv;
-        struct nvidia_softc *sc = devclass_get_softc(nvidia_devclass, i);
-        if (sc == NULL) {
-            continue;
-        }
-        nv = sc->nv_state;
-
-        if (nv->gpu_id == gpu_id) {
-            return nv;
-        }
-    }
-
-    return NULL;
-}
-
 int nvidia_open_dev(
     nv_state_t *nv,
     struct nvidia_filep *filep
@@ -609,25 +590,6 @@ failed:
     return status;
 }
 
-int nvidia_open_dev_kernel(
-    NvU32 gpu_id,
-    nvidia_stack_t *sp /* unused: nvidia_open_dev() will use its own stack */
-)
-{
-    int status;
-    nv_state_t *nv = nvidia_find_state(gpu_id);
-
-    if (nv == NULL) {
-        return EINVAL;
-    }
-
-    nv_lock_api(nv);
-    status = nvidia_open_dev(nv, NULL /* filep */);
-    nv_unlock_api(nv);
-
-    return status;
-}
-
 int nvidia_close_dev(
     nv_state_t *nv,
     struct nvidia_filep *filep
@@ -640,9 +602,7 @@ int nvidia_close_dev(
     sp = sc->sp[NV_DEV_STACK_API];
 
     NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, TRUE);
-    if (filep != NULL) {
-        rm_free_unused_clients(sp, nv, filep);
-    }
+    rm_free_unused_clients(sp, nv, filep);
 
     if (--sc->refcnt == 0) {
         if (sc->UD_object != NULL)
@@ -660,21 +620,6 @@ int nvidia_close_dev(
     return 0;
 }
 
-void nvidia_close_dev_kernel(
-    NvU32 gpu_id,
-    nvidia_stack_t *sp /* unused: nvidia_close_dev() will use its own stack */
-)
-{
-    nv_state_t *nv = nvidia_find_state(gpu_id);
-
-    if (nv == NULL) {
-        return;
-    }
-
-    nv_lock_api(nv);
-    nvidia_close_dev(nv, NULL /* filep */);
-    nv_unlock_api(nv);
-}
 
 int nvidia_modevent(
     module_t mod,
@@ -718,13 +663,6 @@ int nvidia_modevent(
 
             __nvidia_init_sp = sp;
 
-            if (!nvidia_lock_init_locks(sp, &nvidia_ctl_state)) {
-                rm_shutdown_rm(sp);
-                NV_UMA_ZONE_FREE_STACK(sp);
-                uma_zdestroy(nvidia_stack_t_zone);
-                return ENOMEM;
-            }
-
             callout_init(&sc->timer, CALLOUT_MPSAFE);
             sx_init(&sc->api_sx, "ctl.api_sx");
 
@@ -756,9 +694,6 @@ int nvidia_modevent(
             sx_destroy(&sc->api_sx);
 
             sp = __nvidia_init_sp;
-
-            nvidia_lock_destroy_locks(sp, nv);
-
             rm_shutdown_rm(sp);
 
             NV_UMA_ZONE_FREE_STACK(sp);
@@ -777,6 +712,11 @@ int nvidia_modevent(
     return 0;
 }
 
+NvS32 NV_API_CALL nv_no_incoherent_mappings(void)
+{
+    return 1;
+}
+
 void nv_lock_api(nv_state_t *nv)
 {
     struct nvidia_softc *sc = nv->os_state;
@@ -789,38 +729,6 @@ void nv_unlock_api(nv_state_t *nv)
     sx_xunlock(&sc->api_sx);
 }
 
-nv_fd_memdesc_t* NV_API_CALL nv_get_fd_memdesc(
-    void       *file
-)
-{
-    return NULL;
-}
-
-NV_STATUS NV_API_CALL nv_add_fd_memdesc_to_fd(
-    NvU32                  fd,
-    const nv_fd_memdesc_t *pFdMemdesc
-)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
-
-NV_STATUS NV_API_CALL nv_export_rm_object_to_fd(
-    NvHandle  hExportedRmObject,
-    NvS32     fd
-)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
-NV_STATUS NV_API_CALL nv_import_rm_object_from_fd(
-    NvS32     fd,
-    NvHandle *pExportedObject
-)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
 void NV_API_CALL nv_post_event(
     nv_state_t *nv,
     nv_event_t *event,
@@ -952,95 +860,14 @@ NV_STATUS NV_API_CALL nv_free_kernel_mapping(
     return NV_OK;
 }
 
-static nvidia_filep_t* nv_get_file_private(NvU32 fd, nv_state_t *nv)
-{
-    struct file *pFile = NULL;
-    NV_STATUS status = EINVAL;
-    nvidia_filep_t *nvfp = NULL;
-    struct cdev_privdata *p;
-
-#if __FreeBSD_version >= 1000053
-    cap_rights_t rights;
-#endif
-    struct thread *td;
-
-    td = curthread;
-
-    status = fget(td, fd, cap_rights_init(&rights, CAP_READ), &pFile);
-    if (status != 0)
-        return NULL;
-
-    p = pFile->f_cdevpriv;
-    if(!p)
-        goto done;
-
-    if (NV_IS_CTL_DEVICE(nv))
-    {
-        if (p->cdpd_dtr != nvidia_ctl_dtor)
-            goto done;
-    }
-    else
-    {
-        if (p->cdpd_dtr != nvidia_dev_dtor)
-            goto done;
-    }
-
-    nvfp = (nvidia_filep_t*)p->cdpd_data;
-
-done:
-    /*
-     * If we reach here, pFile is a valid struct file pointer, returned
-     * by fget(9).
-     *
-     * fget(9) incremented the struct file's reference count, which
-     * needs to be balanced with a call to fdrop(9).  It is safe to
-     * decrement the reference count before returning filp->private_data
-     * because we are holding the GPUs lock which prevents freeing the file out.
-     */
-    fdrop(pFile, td);
-
-    return nvfp;
-}
-
-NV_STATUS NV_API_CALL nv_add_mapping_context_to_file(
+NV_STATUS NV_API_CALL nv_create_user_mapping_context(
     nv_state_t *nv,
-    nv_usermap_access_params_t* nvuap,
-    NvU32 prot,
-    void *pAllocPriv,
-    NvU64 pageIndex,
-    NvU32 fd
+    NvU64 address,
+    NvU64 size,
+    void **ppPrivate
 )
 {
-    nv_alloc_mapping_context_t *nvamc = NULL;
-    nvidia_filep_t *nvfp = NULL;
-
-    /* Get the nvidia private file data from file descriptor */
-    nvfp = nv_get_file_private(fd, nv);
-    if (nvfp == NULL)
-        return NV_ERR_INVALID_ARGUMENT;
-
-    nvamc = &nvfp->mmap_context;
-
-    if (nvamc->bValid)
-        return NV_ERR_STATE_IN_USE;
-
-    if (NV_IS_CTL_DEVICE(nv))
-    {
-        nvamc->alloc = pAllocPriv;
-        nvamc->page_index = pageIndex;
-    }
-    else
-    {
-        nvamc->mmap_start = nvuap->mmap_start;
-        nvamc->mmap_size = nvuap->mmap_size;
-        nvamc->access_start = nvuap->access_start;
-        nvamc->access_size = nvuap->access_size;
-        nvamc->remap_prot_extra = nvuap->remap_prot_extra;
-    }
-
-    nvamc->prot = prot;
-    nvamc->bValid = NV_TRUE;
-
+    *ppPrivate = NULL;
     return NV_OK;
 }
 
@@ -1465,7 +1292,6 @@ int nvidia_mmap_ctl_single(
     struct nvidia_softc *sc = nv->os_state;
     NvU64 pageIndex;
     NvU32 prot;
-    nv_alloc_mapping_context_t *mmap_context;
 
     sp = sc->sp[NV_DEV_STACK_API];
 
@@ -1473,23 +1299,13 @@ int nvidia_mmap_ctl_single(
     if (rmStatus != NV_OK)
         return EAGAIN;
 
-    mmap_context = &filep->mmap_context;
-
-    /*
-     * If no mmap context exists on this file descriptor, this mapping wasn't
-     * previously validated with the RM so it must be rejected.
-     */
-    if (!mmap_context->bValid)
-    {
-        nv_printf(NV_DBG_ERRORS, "NVRM: VM: invalid mmap\n");
+    rmStatus = rm_validate_mmap_request(sp, nv, filep, *offset,
+            size, &prot, (void **)&at, &pageIndex);
+    if (rmStatus != NV_OK) {
         rm_release_api_lock(sp);
-        return -EINVAL;
+        return EINVAL;
     }
 
-    at = (struct nvidia_alloc *)mmap_context->alloc;
-    pageIndex = mmap_context->page_index;
-    prot = mmap_context->prot;
-
     vm_object_reference(at->object);
     *object = at->object;
     *offset = (pageIndex * PAGE_SIZE);
@@ -1507,21 +1323,19 @@ int nvidia_mmap_dev_single(
     vm_object_t *object
 )
 {
+    nvidia_stack_t *sp;
+    NV_STATUS rmStatus;
     struct nvidia_softc *sc = nv->os_state;
-    nv_alloc_mapping_context_t *mmap_context = &filep->mmap_context;
+    NvU32 prot;
 
-    /*
-     * If no mmap context is valid on this file descriptor then this mapping
-     * wasn't previously validated with the RM so it must be rejected.
-     */
-    if (!mmap_context->bValid)
-    {
-        nv_printf(NV_DBG_ERRORS, "NVRM: VM: invalid mmap\n");
-        return -EINVAL;
-    }
+    sp = sc->sp[NV_DEV_STACK_API];
 
-    *offset = mmap_context->mmap_start;
-    size = mmap_context->mmap_size;
+    NV_PCI_CHECK_CONFIG_SPACE(sp, nv, TRUE, TRUE, TRUE);
+
+    rmStatus = rm_validate_mmap_request(sp, nv, filep, *offset, size,
+            &prot, NULL, NULL);
+    if (rmStatus != NV_OK)
+        return EINVAL;
 
     if (IS_UD_OFFSET(nv, *offset, size)) {
         *object = sc->UD_object;
@@ -1600,7 +1414,7 @@ void NV_API_CALL nv_set_dma_address_size(
 #endif
 }
 
-nv_state_t* NV_API_CALL nv_get_adapter_state(
+void* NV_API_CALL nv_get_adapter_state(
     NvU32 domain,
     NvU8  bus,
     NvU8  slot
@@ -1618,16 +1432,16 @@ nv_state_t* NV_API_CALL nv_get_adapter_state(
 
         if ((nv->pci_info.domain == domain) &&
             (nv->pci_info.bus == bus) && (nv->pci_info.slot == slot)) {
-            return nv;
+            return (void *) nv;
         }
     }
 
-    return NULL;
-}
+    if (NV_PCI_MATCH_CTL_DEVICE(domain, bus, slot)) {
+        nv = &nvidia_ctl_state;
+        return (void *) nv;
+    }
 
-nv_state_t* NV_API_CALL nv_get_ctl_state(void)
-{
-    return &nvidia_ctl_state;
+    return NULL;
 }
 
 void NV_API_CALL nv_verify_pci_config(
@@ -1667,7 +1481,6 @@ NV_STATUS NV_API_CALL nv_dma_map_alloc(
     nv_state_t *nv,
     NvU64       page_count,
     NvU64      *va_array,
-    NvBool      contig,
     void      **priv
 )
 {
@@ -1685,41 +1498,24 @@ NV_STATUS NV_API_CALL nv_dma_unmap_alloc(
 }
 
 NV_STATUS NV_API_CALL nv_dma_map_peer(
-    nv_state_t *nv,
-    nv_state_t *peer,
-    NvU8        bar_index,
-    NvU64       page_count,
-    NvU64      *va
+    nv_state_t    *nv,
+    nv_aperture_t *aperture,
+    NvU64          page_count,
+    NvU64         *va_array
 )
 {
     return NV_ERR_NOT_SUPPORTED;
 }
 
-void NV_API_CALL nv_dma_unmap_peer(
+NV_STATUS NV_API_CALL nv_dma_unmap_peer(
     nv_state_t *nv,
     NvU64       page_count,
-    NvU64       va
-)
-{
-}
-
-NV_STATUS NV_API_CALL nv_dma_map_mmio(
-    nv_state_t *nv,
-    NvU64       page_count,
-    NvU64      *va
+    NvU64      *va_array
 )
 {
     return NV_ERR_NOT_SUPPORTED;
 }
 
-void NV_API_CALL nv_dma_unmap_mmio(
-    nv_state_t *nv,
-    NvU64       page_count,
-    NvU64       va
-)
-{
-}
-
 NV_STATUS NV_API_CALL nv_log_error(
     nv_state_t *nv,
     NvU32       error_number,
@@ -1730,6 +1526,17 @@ NV_STATUS NV_API_CALL nv_log_error(
     return NV_OK;
 }
 
+NV_STATUS NV_API_CALL nv_alloc_os_descriptor_handle(
+    nv_state_t *nv,
+    NvS32       fd,
+    void       *private,
+    NvU64       num_pages,
+    NvU32      *handle
+)
+{
+    return NV_ERR_NOT_SUPPORTED;
+}
+
 NvU64 NV_API_CALL nv_get_dma_start_address(
     nv_state_t *nv
 )
@@ -1776,73 +1583,3 @@ NV_STATUS NV_API_CALL nv_unregister_user_pages(
 {
     return NV_OK;
 }
-
-NV_STATUS NV_API_CALL nv_get_device_memory_config(
-    nv_state_t *nv,
-    NvU32 *pAddrSysPhys,
-    NvU32 *pAddrGuestPhys,
-    NvU32 *pAddrWidth,
-    NvU32 *pGranularity,
-    NvS32 *pNodeId
-)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
-NV_STATUS NV_API_CALL nv_get_usermap_access_params(
-    nv_state_t *nv,
-    nv_usermap_access_params_t *nvuap
-)
-{
-    return NV_OK;
-}
-
-NV_STATUS NV_API_CALL nv_register_peer_io_mem(
-    nv_state_t *nv,
-    NvU64      *phys_addr,
-    NvU64       page_count,
-    void      **priv_data
-)
-{
-    return NV_OK;
-}
-
-void NV_API_CALL nv_unregister_peer_io_mem(
-    nv_state_t *nv,
-    void       *priv_data
-)
-{
-}
-
-NV_STATUS NV_API_CALL nv_get_ibmnpu_genreg_info(
-    nv_state_t *nv,
-    NvU64      *base,
-    NvU64      *size
-)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
-NV_STATUS NV_API_CALL nv_get_ibmnpu_relaxed_ordering_mode(
-    nv_state_t *nv,
-    NvBool *mode
-)
-{
-    return NV_ERR_NOT_SUPPORTED;
-}
-
-void NV_API_CALL nv_register_backlight(
-    nv_state_t *nv,
-    NvU32 displayId,
-    NvU32 currentBrightness
-)
-{
-    /* not implemented */
-}
-
-void NV_API_CALL nv_unregister_backlight(
-    nv_state_t *nv
-)
-{
-    /* not implemented */
-}
