@@ -80,7 +80,6 @@ NV_STATUS   NV_API_CALL  os_delay                    (NvU32);
 NV_STATUS   NV_API_CALL  os_delay_us                 (NvU32);
 NvU64       NV_API_CALL  os_get_cpu_frequency        (void);
 NvU32       NV_API_CALL  os_get_current_process      (void);
-NvU32       NV_API_CALL  os_get_current_pasid        (void);
 NV_STATUS   NV_API_CALL  os_get_current_thread       (NvU64 *);
 char*       NV_API_CALL  os_string_copy              (char *, const char *);
 NvU32       NV_API_CALL  os_string_length            (const char *);
@@ -150,19 +149,13 @@ BOOL        NV_API_CALL  os_iommu_is_snooping_enabled(void);
 NvBool      NV_API_CALL  os_is_xen_dom0              (void);
 NvBool      NV_API_CALL  os_is_vgx_hyper             (void);
 NV_STATUS   NV_API_CALL  os_inject_vgx_msi           (NvU16, NvU64, NvU32);
-NvBool      NV_API_CALL  os_is_grid_supported        (void);
-void        NV_API_CALL  os_get_screen_info          (NvU64 *, NvU64 *);
+NV_STATUS   NV_API_CALL  os_get_screen_info          (NvU64 *, NvU64 *);
 void        NV_API_CALL  os_bug_check                (NvU32, const char *);
 NV_STATUS   NV_API_CALL  os_lock_user_pages          (void *, NvU64, void **);
 NV_STATUS   NV_API_CALL  os_lookup_user_io_memory    (void *, NvU64, NvU64 **);
 NV_STATUS   NV_API_CALL  os_unlock_user_pages        (NvU64, void *);
 NV_STATUS   NV_API_CALL  os_match_mmap_offset        (void *, NvU64, NvU64 *);
 NV_STATUS   NV_API_CALL  os_get_euid                 (NvU32 *);
-NV_STATUS   NV_API_CALL  os_get_smbios_header        (NvU64 *pSmbsAddr);
-NV_STATUS   NV_API_CALL  os_get_acpi_rsdp_from_uefi  (NvU32 *);
-void        NV_API_CALL  os_add_record_for_crashLog  (void *, NvU32);
-void        NV_API_CALL  os_delete_record_for_crashLog (void *);
-
 /*
  * ---------------------------------------------------------------------------
  *
@@ -233,6 +226,5 @@ void NV_API_CALL  nv_prints(NvU32 debuglevel, const char *string);
 #define OS_PAGE_SHIFT               (os_get_page_shift())
 
 #define IS_VGX_HYPER()              os_is_vgx_hyper()
-#define IS_GRID_SUPPORTED()         os_is_grid_supported()
 
 #endif /* _OS_INTERFACE_H_ */
